@@ -28,13 +28,13 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '1.3'
+__version__ = '1.4'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp',)
 
 AUDIO = ('.wav', '.mp3', '.aac', '.ogg', '.oga', '.flac',)
-VIDEO = ('.mp4', '.mpg', '.avi', '.mkv',)
+VIDEO = ('.mp4', '.mpg', '.avi', '.mkv', '.flv', )
 
 DOCUMENTS = ('.pdf', '.rtf', '.txt', '.md', '.mdown', '.rst',
     '.odf', '.odp', '.ods', '.odg', '.ott', '.otp', '.ots', '.otg',
@@ -51,6 +51,19 @@ DEFAULT = IMAGES + AUDIO + DOCUMENTS
 
 ALL = IMAGES + AUDIO + VIDEO + DOCUMENTS + DATA + ARCHIVES
 
+OPENXML_MIMETYPES = {
+    '.xlsx': 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
+    '.xltx': 'application/vnd.openxmlformats-officedocument.spreadsheetml.template',
+    '.potx': 'application/vnd.openxmlformats-officedocument.presentationml.template',
+    '.ppsx': 'application/vnd.openxmlformats-officedocument.presentationml.slideshow',
+    '.pptx': 'application/vnd.openxmlformats-officedocument.presentationml.presentation',
+    '.sldx': 'application/vnd.openxmlformats-officedocument.presentationml.slide',
+    '.docx': 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
+    '.dotx': 'application/vnd.openxmlformats-officedocument.wordprocessingml.template',
+    '.xlam': 'application/vnd.ms-excel.addin.macroEnabled.12',
+    '.xlsb': 'application/vnd.ms-excel.sheet.binary.macroEnabled.12',
+}
+
 
 class FileStorage(object):
     
@@ -274,11 +287,14 @@ class FileStorage(object):
                 pass
             raise RequestEntityTooLarge
         
+        _, ext = os.path.splitext(filepath)
+        content_type = OPENXML_MIMETYPES.get(ext, filesto.content_type)
+
         data = {
             'name': filename,
             'relpath': filepath,
             'size': filesize,
-            'content_type': filesto.content_type,
+            'content_type': content_type,
             'remote_url': None,
         }
         return File(data, self.base_path, self.base_url)
@@ -320,7 +336,7 @@ class File(object):
         self.name = data.get('name', u'')
         self.relpath = data.get('relpath', '').strip('/')
         self.size = data.get('size', u'')
-        self.type = data.get('type', u'')
+        self.content_type = data.get('content_type', u'')
         self.remote_url = data.get('remote_url')
 
         self.width = data.get('width')
@@ -329,7 +345,7 @@ class File(object):
         self.base_path = base_path.rstrip('/')
         self.base_url = base_url.rstrip('/')
         
-        self.is_image = self.type.startswith('image/')
+        self.is_image = self.content_type.startswith('image/')
 
         path = ''
         if self.relpath:
@@ -366,7 +382,7 @@ class File(object):
             'name': self.name,
             'relpath': self.relpath,
             'size': self.size,
-            'type': self.type,
+            'content_type': self.content_type,
             'url': self.url,
             'remote_url': self.remote_url,
         }
